@@ -1,5 +1,5 @@
 /*
- * "$Id: escp2-papers.c,v 1.99 2006/05/31 23:15:22 rlk Exp $"
+ * "$Id: escp2-papers.c,v 1.99.8.1 2007/03/02 12:01:26 rlk Exp $"
  *
  *   Print plug-in EPSON ESC/P2 driver for the GIMP.
  *
@@ -531,20 +531,20 @@ static const char r800_glossy_hue_adj[] =
 "</curve>\n"
 "</gutenprint>\n";
 
-#define DECLARE_PAPERS(name)				\
-const paperlist_t stpi_escp2_##name##_paper_list =	\
-{							\
-  #name,						\
-  sizeof(name##_papers) / sizeof(paper_t),		\
-  name##_papers						\
+#define DECLARE_PAPERS(name)			\
+static const paperlist_t name##_paper_list =	\
+{						\
+  #name,					\
+  sizeof(name##_papers) / sizeof(paper_t),	\
+  name##_papers					\
 }
 
-#define DECLARE_PAPER_ADJUSTMENTS(name)					  \
-const paper_adjustment_list_t stpi_escp2_##name##_paper_adjustment_list = \
-{									  \
-  #name,								  \
-  sizeof(name##_adjustments) / sizeof(paper_adjustment_t),		  \
-  name##_adjustments							  \
+#define DECLARE_PAPER_ADJUSTMENTS(name)					\
+static const paper_adjustment_list_t name##_paper_adjustment_list =	\
+{									\
+  #name,								\
+  sizeof(name##_adjustments) / sizeof(paper_adjustment_t),		\
+  name##_adjustments							\
 }
 
 static const paper_adjustment_t standard_adjustments[] =
@@ -1440,3 +1440,470 @@ static const paper_t picturemate_papers[] =
 };
 
 DECLARE_PAPERS(picturemate);
+
+typedef struct
+{
+  const char *name;
+  const paperlist_t *paper_list;
+} paperl_t;
+
+static const paperl_t the_papers[] =
+{
+  { "standard", &standard_paper_list },
+  { "durabrite", &durabrite_paper_list },
+  { "durabrite2", &durabrite2_paper_list },
+  { "ultrachrome", &ultrachrome_paper_list },
+  { "ultrachrome_k3", &ultrachrome_k3_paper_list },
+  { "r800", &r800_paper_list },
+  { "picturemate", &picturemate_paper_list },
+};
+
+const paperlist_t *
+stpi_escp2_get_paperlist_named(const char *n)
+{
+  int i;
+  if (n)
+    for (i = 0; i < sizeof(the_papers) / sizeof(paperl_t); i++)
+      {
+	if (strcmp(n, the_papers[i].name) == 0)
+	  return the_papers[i].paper_list;
+      }
+  return NULL;
+}
+
+typedef struct
+{
+  const char *name;
+  const paper_adjustment_list_t *paper_list;
+} paperadj_t;
+
+static const paperadj_t the_adjustments[] =
+{
+  { "standard", &standard_paper_adjustment_list },
+  { "durabrite", &durabrite_paper_adjustment_list },
+  { "durabrite2", &durabrite2_paper_adjustment_list },
+  { "photo", &photo_paper_adjustment_list },
+  { "photo2", &photo2_paper_adjustment_list },
+  { "photo3", &photo3_paper_adjustment_list },
+  { "sp960", &sp960_paper_adjustment_list },
+  { "ultrachrome_photo", &ultrachrome_photo_paper_adjustment_list },
+  { "ultrachrome_matte", &ultrachrome_matte_paper_adjustment_list },
+  { "ultrachrome_k3_photo", &ultrachrome_k3_photo_paper_adjustment_list },
+  { "ultrachrome_k3_matte", &ultrachrome_k3_matte_paper_adjustment_list },
+  { "r800_photo", &r800_photo_paper_adjustment_list },
+  { "r800_matte", &r800_matte_paper_adjustment_list },
+  { "picturemate", &picturemate_paper_adjustment_list },
+};
+
+const paper_adjustment_list_t *
+stpi_escp2_get_paper_adjustment_list_named(const char *n)
+{
+  int i;
+  if (n)
+    for (i = 0; i < sizeof(the_adjustments) / sizeof(paperadj_t); i++)
+      {
+	if (strcmp(n, the_adjustments[i].name) == 0)
+	  return the_adjustments[i].paper_list;
+      }
+  return NULL;
+}
+
+
+#define DECLARE_INPUT_SLOT(name)				\
+static const input_slot_list_t name##_input_slot_list =		\
+{								\
+  #name,							\
+  name##_input_slots,						\
+  sizeof(name##_input_slots) / sizeof(const input_slot_t),	\
+}
+
+static const input_slot_t standard_roll_feed_input_slots[] =
+{
+  {
+    "Standard",
+    N_("Standard"),
+    0,
+    0,
+    0,
+    { 16, "IR\002\000\000\001EX\006\000\000\000\000\000\005\000" },
+    { 6, "IR\002\000\000\000"}
+  },
+  {
+    "Roll",
+    N_("Roll Feed"),
+    0,
+    1,
+    ROLL_FEED_DONT_EJECT,
+    { 16, "IR\002\000\000\001EX\006\000\000\000\000\000\005\001" },
+    { 6, "IR\002\000\000\002" }
+  }
+};
+
+DECLARE_INPUT_SLOT(standard_roll_feed);
+
+static const input_slot_t cutter_roll_feed_input_slots[] =
+{
+  {
+    "Standard",
+    N_("Standard"),
+    0,
+    0,
+    0,
+    { 16, "IR\002\000\000\001EX\006\000\000\000\000\000\005\000" },
+    { 6, "IR\002\000\000\000"}
+  },
+  {
+    "RollCutPage",
+    N_("Roll Feed (cut each page)"),
+    0,
+    1,
+    ROLL_FEED_CUT_ALL,
+    { 16, "IR\002\000\000\001EX\006\000\000\000\000\000\005\001" },
+    { 6, "IR\002\000\000\002" }
+  },
+  {
+    "RollCutNone",
+    N_("Roll Feed (do not cut)"),
+    0,
+    1,
+    ROLL_FEED_DONT_EJECT,
+    { 16, "IR\002\000\000\001EX\006\000\000\000\000\000\005\001" },
+    { 6, "IR\002\000\000\002" }
+  }
+};
+
+DECLARE_INPUT_SLOT(cutter_roll_feed);
+
+static const input_slot_t cd_cutter_roll_feed_input_slots[] =
+{
+  {
+    "Standard",
+    N_("Standard"),
+    0,
+    0,
+    0,
+    { 23, "IR\002\000\000\001EX\006\000\000\000\000\000\005\000PP\003\000\000\001\377" },
+    { 6, "IR\002\000\000\000"}
+  },
+  {
+    "Manual",
+    N_("Manual Feed"),
+    0,
+    0,
+    0,
+    { 36, "PM\002\000\000\000IR\002\000\000\001EX\006\000\000\000\000\000\005\000FP\003\000\000\000\000PP\003\000\000\002\001" },
+    { 6, "IR\002\000\000\000"}
+  },
+  {
+    "CD",
+    N_("Print to CD"),
+    1,
+    0,
+    0,
+    { 36, "PM\002\000\000\000IR\002\000\000\001EX\006\000\000\000\000\000\005\000FP\003\000\000\000\000PP\003\000\000\002\001" },
+    { 6, "IR\002\000\000\000"}
+  },
+  {
+    "RollCutPage",
+    N_("Roll Feed (cut each page)"),
+    0,
+    1,
+    ROLL_FEED_CUT_ALL,
+    { 23, "IR\002\000\000\001EX\006\000\000\000\000\000\005\001PP\003\000\000\001\377" },
+    { 6, "IR\002\000\000\002" }
+  },
+  {
+    "RollCutNone",
+    N_("Roll Feed (do not cut)"),
+    0,
+    1,
+    ROLL_FEED_DONT_EJECT,
+    { 23, "IR\002\000\000\001EX\006\000\000\000\000\000\005\001PP\003\000\000\001\377" },
+    { 6, "IR\002\000\000\002" }
+  }
+};
+
+DECLARE_INPUT_SLOT(cd_cutter_roll_feed);
+
+static const input_slot_t cd_roll_feed_input_slots[] =
+{
+  {
+    "Standard",
+    N_("Standard"),
+    0,
+    0,
+    0,
+    { 23, "IR\002\000\000\001EX\006\000\000\000\000\000\005\000PP\003\000\000\001\377" },
+    { 6, "IR\002\000\000\000"}
+  },
+  {
+    "Manual",
+    N_("Manual Feed"),
+    0,
+    0,
+    0,
+    { 36, "PM\002\000\000\000IR\002\000\000\001EX\006\000\000\000\000\000\005\000FP\003\000\000\000\000PP\003\000\000\002\001" },
+    { 6, "IR\002\000\000\000"}
+  },
+  {
+    "CD",
+    N_("Print to CD"),
+    1,
+    0,
+    0,
+    { 36, "PM\002\000\000\000IR\002\000\000\001EX\006\000\000\000\000\000\005\000FP\003\000\000\000\000PP\003\000\000\002\001" },
+    { 6, "IR\002\000\000\000"}
+  },
+  {
+    "Roll",
+    N_("Roll Feed"),
+    0,
+    1,
+    ROLL_FEED_DONT_EJECT,
+    { 23, "IR\002\000\000\001EX\006\000\000\000\000\000\005\001PP\003\000\000\001\377" },
+    { 6, "IR\002\000\000\002" }
+  }
+};
+
+DECLARE_INPUT_SLOT(cd_roll_feed);
+
+static const input_slot_t r2400_input_slots[] =
+{
+  {
+    "Standard",
+    N_("Standard"),
+    0,
+    0,
+    0,
+    { 23, "IR\002\000\000\001EX\006\000\000\000\000\000\005\000PP\003\000\000\001\377" },
+    { 6, "IR\002\000\000\000"}
+  },
+  {
+    "Velvet",
+    N_("Manual Sheet Guide"),
+    0,
+    0,
+    0,
+    { 23, "IR\002\000\000\001EX\006\000\000\000\000\000\005\000PP\003\000\000\003\000" },
+    { 6, "IR\002\000\000\000"}
+  },
+  {
+    "Matte",
+    N_("Manual Feed (Front)"),
+    0,
+    0,
+    0,
+    { 23, "IR\002\000\000\001EX\006\000\000\000\000\000\005\000PP\003\000\000\002\000" },
+    { 6, "IR\002\000\000\000"}
+  },
+  {
+    "Roll",
+    N_("Roll Feed"),
+    0,
+    1,
+    ROLL_FEED_DONT_EJECT,
+    { 23, "IR\002\000\000\001EX\006\000\000\000\000\000\005\001PP\003\000\000\003\001" },
+    { 6, "IR\002\000\000\002" }
+  }
+};
+
+DECLARE_INPUT_SLOT(r2400);
+
+static const input_slot_t r1800_input_slots[] =
+{
+  {
+    "Standard",
+    N_("Standard"),
+    0,
+    0,
+    0,
+    { 23, "IR\002\000\000\001EX\006\000\000\000\000\000\005\000PP\003\000\000\001\377" },
+    { 6, "IR\002\000\000\000"}
+  },
+  {
+    "Velvet",
+    N_("Manual Sheet Guide"),
+    0,
+    0,
+    0,
+    { 23, "IR\002\000\000\001EX\006\000\000\000\000\000\005\000PP\003\000\000\003\000" },
+    { 6, "IR\002\000\000\000"}
+  },
+  {
+    "Matte",
+    N_("Manual Feed (Front)"),
+    0,
+    0,
+    0,
+    { 23, "IR\002\000\000\001EX\006\000\000\000\000\000\005\000PP\003\000\000\002\000" },
+    { 6, "IR\002\000\000\000"}
+  },
+  {
+    "Roll",
+    N_("Roll Feed"),
+    0,
+    1,
+    ROLL_FEED_DONT_EJECT,
+    { 23, "IR\002\000\000\001EX\006\000\000\000\000\000\005\001PP\003\000\000\003\001" },
+    { 6, "IR\002\000\000\002" }
+  },
+  {
+    "CD",
+    N_("Print to CD"),
+    1,
+    0,
+    0,
+    { 36, "PM\002\000\000\000IR\002\000\000\001EX\006\000\000\000\000\000\005\000FP\003\000\000\000\000PP\003\000\000\002\001" },
+    { 6, "IR\002\000\000\000"}
+  },
+};
+
+DECLARE_INPUT_SLOT(r1800);
+
+static const input_slot_t rx700_input_slots[] =
+{
+  {
+    "Rear",
+    N_("Rear Tray"),
+    0,
+    0,
+    0,
+    { 23, "IR\002\000\000\001EX\006\000\000\000\000\000\005\000PP\003\000\000\001\000" },
+    { 6, "IR\002\000\000\000"}
+  },
+  {
+    "Front",
+    N_("Front Tray"),
+    0,
+    0,
+    0,
+    { 23, "IR\002\000\000\001EX\006\000\000\000\000\000\005\000PP\003\000\000\001\001" },
+    { 6, "IR\002\000\000\000"}
+  },
+  {
+    "CD",
+    N_("Print to CD"),
+    1,
+    0,
+    0,
+    { 36, "PM\002\000\000\000IR\002\000\000\001EX\006\000\000\000\000\000\005\000FP\003\000\000\000\000PP\003\000\000\002\001" },
+    { 6, "IR\002\000\000\000"}
+  },
+  {
+    "PhotoBoard",
+    N_("Photo Board"),
+    0,
+    0,
+    0,
+    { 23, "IR\002\000\000\001EX\006\000\000\000\000\000\005\000PP\003\000\000\002\000" },
+    { 6, "IR\002\000\000\000"}
+  },
+};
+
+DECLARE_INPUT_SLOT(rx700);
+
+static const input_slot_t pro_roll_feed_input_slots[] =
+{
+  {
+    "Standard",
+    N_("Standard"),
+    0,
+    0,
+    0,
+    { 7, "PP\003\000\000\002\000" },
+    { 0, "" }
+  },
+  {
+    "Roll",
+    N_("Roll Feed"),
+    0,
+    1,
+    0,
+    { 7, "PP\003\000\000\003\000" },
+    { 0, "" }
+  }
+};
+
+DECLARE_INPUT_SLOT(pro_roll_feed);
+
+static const input_slot_t spro5000_input_slots[] =
+{
+  {
+    "CutSheet1",
+    N_("Cut Sheet Bin 1"),
+    0,
+    0,
+    0,
+    { 7, "PP\003\000\000\001\001" },
+    { 0, "" }
+  },
+  {
+    "CutSheet2",
+    N_("Cut Sheet Bin 2"),
+    0,
+    0,
+    0,
+    { 7, "PP\003\000\000\002\001" },
+    { 0, "" }
+  },
+  {
+    "CutSheetAuto",
+    N_("Cut Sheet Autoselect"),
+    0,
+    0,
+    0,
+    { 7, "PP\003\000\000\001\377" },
+    { 0, "" }
+  },
+  {
+    "ManualSelect",
+    N_("Manual Selection"),
+    0,
+    0,
+    0,
+    { 7, "PP\003\000\000\002\001" },
+    { 0, "" }
+  }
+};
+
+DECLARE_INPUT_SLOT(spro5000);
+
+static const input_slot_list_t default_input_slot_list =
+{
+  "Standard",
+  NULL,
+  0,
+};
+
+typedef struct
+{
+  const char *name;
+  const input_slot_list_t *input_slots;
+} inslot_t;
+
+static const inslot_t the_slots[] =
+{
+  { "cd_cutter_roll_feed", &cd_cutter_roll_feed_input_slot_list },
+  { "cd_roll_feed", &cd_roll_feed_input_slot_list },
+  { "cutter_roll_feed", &cutter_roll_feed_input_slot_list },
+  { "default", &default_input_slot_list },
+  { "pro_roll_feed", &pro_roll_feed_input_slot_list },
+  { "r1800", &r1800_input_slot_list },
+  { "r2400", &r2400_input_slot_list },
+  { "rx700", &rx700_input_slot_list },
+  { "spro5000", &spro5000_input_slot_list },
+  { "standard_roll_feed", &standard_roll_feed_input_slot_list },
+};
+
+const input_slot_list_t *
+stpi_escp2_get_input_slot_list_named(const char *n)
+{
+  int i;
+  if (n)
+    for (i = 0; i < sizeof(the_slots) / sizeof(inslot_t); i++)
+      {
+	if (strcmp(n, the_slots[i].name) == 0)
+	  return the_slots[i].input_slots;
+      }
+  return NULL;
+}
